@@ -1,7 +1,7 @@
 # --------------------------------------------------------------------------- #
 #   DisplayLang                                                               #
 #                                                                             #
-#   Copyright (c) 2020-2022 DisplayLang contributors                          #
+#   Copyright (c) 2020-2023 DisplayLang Contributors                          #
 #                                                                             #
 #   Licensed under the Apache License, Version 2.0 (the "License");           #
 #   you may not use this file except in compliance with the License.          #
@@ -92,7 +92,7 @@ class DisplayLangEvaluator(ExpressionEvaluator):
                 for i in address:
                     try:
                         v = v[i]
-                    except IndexError:
+                    except (IndexError, TypeError):
                         msg = 'Cannot unpack assignment.'
                         reject(msg, node)
                 self.add_current_name(target_name, v)
@@ -219,7 +219,7 @@ class DisplayLangEvaluator(ExpressionEvaluator):
         for name in names:
             if name in prev_bound_values:
                 self.bound_vars[name] = prev_bound_values[name]
-            else:
+            elif name in self.bound_vars:
                 del self.bound_vars[name]
 
         return L
@@ -365,7 +365,7 @@ class DisplayLangProcessor:
             # We want such exceptions to be wrapped in `ControlledEvaluationException`
             # and re-raised in this form.
             except Exception as e:
-                raise ControlledEvaluationException(str(e)) from e
+                raise ControlledEvaluationException(repr(e)) from e
             if isinstance(result, ast.Return):
                 val = result.value
                 if not isinstance(val, str):
